pub struct ConfirmedCoupling { /* private fields */ }Expand description
The two calls and routed inboxes produced by an early coupling once both dialogs confirm.
Implementations
Sourceimpl ConfirmedCoupling
impl ConfirmedCoupling
Sourcepub fn into_parts(self) -> (Coupling, Receiver<Incoming>, Receiver<Incoming>)
pub fn into_parts(self) -> (Coupling, Receiver<Incoming>, Receiver<Incoming>)
Take the confirmed owner and its two routed request streams.