#[non_exhaustive]pub struct DrainReport {
pub completed: bool,
pub remaining: DrainProgress,
pub terminated_dialogs: usize,
pub terminated_transactions: usize,
pub counts: DispatchCounts,
}Expand description
Terminal result of Dispatcher::drain.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.completed: boolTrue when every route and transaction ended before the deadline.
remaining: DrainProgressLast state observed before natural completion or forced cleanup.
terminated_dialogs: usizeDialog routes explicitly closed at deadline expiry.
terminated_transactions: usizeEndpoint transaction state explicitly terminated at deadline expiry.
counts: DispatchCountsDispatcher decisions accumulated through the drain.