#[non_exhaustive]pub enum DialogSessionAction {
Refresh,
Expire,
}Expand description
The explicit timer input a host must drive before restoration can continue.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Refresh
This side must originate the negotiated refresh.
Expire
The peer’s refresh did not arrive and the session must expire.