EventSubscriptionCounts

Struct EventSubscriptionCounts 

pub struct EventSubscriptionCounts {
    pub active_tasks: usize,
    pub active_timers: usize,
    pub active_transactions: usize,
    pub started_tasks: u64,
    pub finished_tasks: u64,
    pub shed: u64,
}
Runtime resource measurements for outbound event subscriptions.

Fields

active_tasks: usize

Live lifecycle tasks.

active_timers: usize

Live timer tasks.

active_transactions: usize

SUBSCRIBE transactions whose final result is still being observed.

started_tasks: u64

Lifecycle tasks started since construction.

finished_tasks: u64

Lifecycle tasks which exited.

shed: u64

NOTIFY requests refused because a bounded driver queue was full.