pub struct EventSubscriptionCounts {
pub active_tasks: usize,
pub active_timers: usize,
pub active_transactions: usize,
pub started_tasks: u64,
pub finished_tasks: u64,
pub shed: u64,
}Expand description
Runtime resource measurements for outbound event subscriptions.
Fields
active_tasks: usizeLive lifecycle tasks.
active_timers: usizeLive timer tasks.
active_transactions: usizeSUBSCRIBE transactions whose final result is still being observed.
started_tasks: u64Lifecycle tasks started since construction.
finished_tasks: u64Lifecycle tasks which exited.
shed: u64NOTIFY requests refused because a bounded driver queue was full.